#
# spec file for package gjs
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%if 0%{suse_version} > 1130
%define xulrunner_ver 20
%else
%if 0%{suse_version} > 1120
%define xulrunner_ver 192
%else
%define xulrunner_ver 191
%endif
%endif

Name:           gjs
Version:        0.7.11
Release:        1.3.1
# FIXME: find out if tapsets should really be in devel package or in main package
License:        MIT License (or similar)
Summary:        JavaScript bindings based on gobject-introspection and Mozilla
Group:          Development/Libraries/GNOME
Url:            http://live.gnome.org/Gjs
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  gcc-c++
BuildRequires:  mozilla-xulrunner%{xulrunner_ver}-devel
BuildRequires:  python
BuildRequires:  readline-devel
BuildRequires:  systemtap-sdt-devel
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gobject-introspection-1.0)
Requires:       libgjs0 = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%package -n libgjs0
License:        MIT License (or similar)
Summary:        JavaScript bindings based on gobject-introspection and Mozilla
Group:          Development/Libraries/GNOME
# Explicitly requires the xulrunner version we need, instead of hoping we'll
# get the right one with the libmozjs.so Requires.
Requires:       mozilla-xulrunner%{xulrunner_ver}
Provides:       libgjs-0 = %{version}
Obsoletes:      libgjs-0 < %{version}

%description -n libgjs0
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%package -n libgjs-devel
License:        MIT License (or similar)
Summary:        JavaScript bindings based on gobject-introspection and Mozilla
Group:          Development/Libraries/GNOME
Requires:       libgjs0 = %{version}
Requires:       mozilla-xulrunner%{xulrunner_ver}-devel
# Just a helper provides
Provides:       gjs-devel = %{version}

%description -n libgjs-devel
This module contains JavaScript bindings based on gobject-introspection and the
Mozilla SpiderMonkey JavaScript engine.

%prep
%setup -q

%build
%configure \
    --disable-static \
    --enable-systemtap
make %{?_smp_mflags}

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
# fix installation of systemtap files
mv %{buildroot}%{buildroot}%{_datadir}/systemtap %{buildroot}%{_datadir}/systemtap

%clean
rm -rf %{buildroot}

%post -n libgjs0 -p /sbin/ldconfig

%postun -n libgjs0 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%{_bindir}/*

%files -n libgjs0
%defattr(-,root,root)
%doc COPYING NEWS README
%{_datadir}/gjs-1.0/
%{_libdir}/*.so.*
%{_libdir}/gjs-1.0/

%files -n libgjs-devel
%defattr(-,root,root)
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_datadir}/systemtap/tapset/*.stp

%changelog
* Tue Mar  1 2011 dimstar@opensuse.org
- Update to version 0.7.11:
  + Add gjs_context_maybe_gc() which is similar to JS_MaybeGC but
    tries to account for native allocations made directly from libc
    when determining if GC is useful. Also invoke after creating
    new native objects.
  + Adapt to additional xulrunner 2.0 changes
  + Add back debugger module, with single nativeTrap() function to
    trigger debugger breakpoint
  + Fix bug with looking up namespaced native modules
  + Memory leak fix
  + Build fixes
- Drop gjs-xulrunner20b11-fix.patch: fixed upstream.
- This update addresses bnc#676079.
* Mon Feb 21 2011 vuntz@opensuse.org
- Add gjs-xulrunner20b11-fix.patch to adapt to API changes in
  latest xulrunner.
* Thu Jan 27 2011 vuntz@opensuse.org
- Update to version 0.7.10:
  + xul2: use JS_NewCompartmentAndGlobalObject to avoid crash with
    latest xulrunner 2.
  + console: don't segfault on huge lines
* Mon Jan 17 2011 vuntz@opensuse.org
- Update to version 0.7.9:
  + Adapt to JS_GetStringChars removal in xulrunner 2.
  + Handle wide ranging enum values better.
  + Some tests fixes.
- Add Url tag.
* Wed Dec 22 2010 dimstar@opensuse.org
- Update to version 0.7.8:
  + Add a js-version property the GjsContext object and also allow
    specifying a specific version via a comment of the form
    '// application/javascript;version=1.8'. If no version is
    specified, all SpiderMonkey extensions are allowed.
  + Integrate with cairo-gobject library for support of boxed
    Cairo types
  + Add support for (out caller-allocates)
  + Add support for gunichar type
  + Support signals with G_TYPE_POINTER argument using
    introspection information
  + When invoking callback for void-returning async D-Bus method
    implementations, allow empty parameter list instead of []
  + Ignore empty elements in the module search path instead of
    treating them as the current directory
  + Handle removal of JS_GetStringBytes() in Spidermonkey
  + Handle removal of JS_GetFunctionName() in Spidermonkey
  + Use new g_object_info_find_method_using_interfaces() to allow
    future caching.
  + Improve efficiency of module search
  + Fix problems with JS_Add/RemoveRoot pairing
  + Memory management fixes
  + Improve error and debugging messages
  + Build fixes
  + Bugs fixed: bgo#624811, bgo#632551, bgo#632626, bgo#632925,
    bgo#633199, bgo#633477, bgo#635359, bgo#635368, bgo#635371,
    bgo#635707, bgo#636263, bgo#636619, bgo#636927, bgo#636928,
    bgo#637246
* Fri Dec  3 2010 vuntz@opensuse.org
- Add explicit Requires of mozilla-xulrunner%%{xulrunner_ver} to
  libgjs0: the Requires on libmozjs.so is not enough, as there
  might be more than one provider, and it could be the wrong
  version of xulrunner.
* Tue Nov 16 2010 dimstar@opensuse.org
- Update to version 0.7.7:
  + bgo#632159: Adapt to removal of SlowNative functions
  + Support more recent development versions of XulRunner.
* Mon Nov 15 2010 dimstar@opensuse.org
- Update to version 0.7.6:
  + bgo#610859: Add makeProxyClass() function to the dbus module
    for easy creation of proxy classes.
  + Add an extra test case.
  + Build fixes.
* Thu Oct 28 2010 prusnak@opensuse.org
- Use pkgconfig BuildRequires when possible:
  + old BuildRequires: cairo-devel, dbus-1-glib-devel,
    gobject-introspection-devel.
  + new BuildRequires: cairo, dbus-glib-1 and
    gobject-introspection-1.0.
- Rename libgjs-0 to libgjs0: this is the correct SLPP name. Add
  appropriate Provides/Obsoletes.
- Do not add explicit Requires of dbus-1-devel and
  gobject-introspection-devel for libgjs-devel: they will be added
  automatically.
- Use %%_smp_mflags, make and %%make_install, following our new best
  packaging practices.
* Thu Oct 28 2010 vuntz@opensuse.org
- Update to version 0.7.5:
  + Replace JS_SealObject by JS_FreezeObject.
  + Port all functions to JSFUN_FAST_NATIVE.
  + JS_IsNativeFrame replaced by JS_IsScriptFrame.
  + Separate "basic" API from "embedder/module".
  + Build fixes.
- Build against mozilla-xulrunner20 in 11.4 and later, and stop
  supporting the 11.1 build (that was using mozilla-xulrunner190).
* Tue Oct  5 2010 vuntz@opensuse.org
- Update to version 0.7.4:
  + Require single include use of headers.
  + Support xulrunner 1.9.3.
  + Make gjs_profiler_reset public.
  + Remove "debugger" module.
  + Replace call context with a concept of "current context".
  + Replace "load context" with a "import global".
  + Various other fixes.
- Drop gjs_gi_probes.d, gjs.stp.in source files: they are now
  included in tarball.
* Thu Sep 16 2010 vuntz@opensuse.org
- Update to version 0.7.2:
  + Fix 64 bit issues.
  + Explicitly link gjs-console against glib.
  + Update to (and require) gobject-introspection 0.9.5.
  + Various other fixes.
- Remove gir-repository Recommends: all the interesting gir files
  are now directly shipped with the libraries.
* Fri Jul 23 2010 vuntz@opensuse.org
- Update to version 0.7.1:
  + Add support for GArray to gjs_value_from_g_argument
  + Add support for GArray to gjs_value_to_g_argument
  + Add support for dtrace/SystemTap
  + Add a promise module
  + Handle GValues of type G_TYPE_STRV
  + [gdb-check] Add a script for easier use
  + Throw a better warning for GValues containing container types
  + [importer] Allow native modules in gjs.so
  + [gjs] Add a byteArray module.
  + Adjust for g-i change to remove machine-independent type tags
  + Various other fixes.
- Drop gjs-bgo623775.patch: fixed upstream.
- Enable systemtap support: add systemtap-sdt-devel BuildRequires,
  pass --enable-systemtap to configure. Add gjs_gi_probes.d and
  gjs.stp.in source files, which are missing from the tarball
  (bgo#625090).
* Thu Jul 15 2010 dimstar@opensuse.org
- Add gjs-bgo623775.patch, from upstream git to fix build with
  gobject-introspection 0.9.2.
* Fri May 28 2010 dimstar@opensuse.org
- Update to version 0.7:
  + Add support for "foreign structs" - which are structures that
    are referenced from gobject-introspection, but need glue
    code to actually handle them.
  + Hook cairo bindings to integrate with gobject-introspected
    libraries using new foreign struct support
  + Start working toward thread-safety by adding
    JS_BeginRequest/JS_EndRequest calls throughout the codebase
  + add Tweener.setTimeScale and Tweener.getTimeScale
  + Wrap cairo_copy_path, cairo_copy_path_flat, and
    cairo_append_path
  + Handle destroy callbacks of type other than GDestroyNotify
  + Handle flag arguments not registered with GObject
  + Log errors that occur in callbacks
  + Code cleanup
  + Build fixes
  + Bugs fixed: bgo#610357, bgo#614055, bgo#614344, bgo#615078,
    bgo#615222, bgo#617343, bgo#617568, bgo#617702, bgo#617972,
    bgo#618190, bgo#618195, bgo#618200, bgo#618201
* Fri Mar 26 2010 vuntz@opensuse.org
- Build against mozilla-xulrunner192-devel on openSUSE > 11.2.
- Add dbus-1-devel Requires to devel package.
* Fri Mar 19 2010 dimstar@opensuse.org
- Update to version 0.6:
  + Optimize function invocation using libffi directly, speeding up
    function invocation benchmarks by as much as 30%%.
  + Add a native Cairo module
  + Don't include user_data arguments for callbacks, in Javascript
    you should use closures instead
  + Add a --command/-c argument to gjs-console
  + Add gjs_context_get_native_context() to allow access to the
    native context
  + Improve internal API support for collecting function arguments
    and defining types
  + Add examples using gio and libsoup
  + Add datadir/share/gjs-1.0 to searchpath in addition to
    XDG_DATA_DIRS
  + Add -rpath for libmozjs when linking gjs-console
  + Improve test cases and add internal assertions
  + Bugs fixed: bgo#561524, bgo#604074, bgo#604076, bgo#606258,
    bgo#609691, bgo#609830, bgo#610320, bgo#610370, bgo#610574,
    bgo#611529, bgo#611585, bgo#611590, bgo#611591, bgo#611811.
    bgo#613106
- BuildRequire cairo-devel.
* Tue Feb 16 2010 dimstar@opensuse.org
- Update to version 0.5:
  + Add a test for DBus.getcurrentMessageContext()
  + [dbus] include service name in error messages
  + gjs_define_object_class(): generate correct object hierarchy
  + Log the gjs-console command-line on startup
  + move gjs_error_reporter into a C++ file jsapi-private.cpp
  + don't use PTRDIFF macro from private spidermonkey header
  + Require C++
  + bgo#584558 - Need print() function
  + Enable JIT if we can, by default
  + Make things build with glib 2.16
  + Allow null/undefined to be passed in to callbacks
  + Support for callback functions
- BuildRequire gcc-c++.
* Wed Aug 26 2009 vuntz@novell.com
- Update to version 0.4:
  + Use g_boxed methods for GValue copying/freeing
  + Add symbolic link from gjs to gjs-console in $(bindir)
  + Use gssize in gjs_string_from_utf8/gjs_string_from_filename
  + Don't use undefined variable in dbus exception
  + Add gjs_parse_args
  + Add a gettext module
  + Better toString() for introspection objects
  +  Port modules/mainloop to gjs_parse_args
  + scripts: don't hardcode path to python
  + switch DEBUG_DBUS_MARSHAL log messages to be compiled out by
    default
  + bgo#560048 - Use JS_SetPropertyAttributes to seal imports
  + autoconf-2.64 compat: Don't use $(builddir) or
    $(abs_top_builddir)
  + Fix gjs_crash_after_timeout() problems
* Thu Aug  6 2009 vuntz@novell.com
- Build against mozilla-xulrunner191.
* Tue Jul  7 2009 vuntz@novell.com
- Update to version 0.3:
  + DBus support
  + Support simple fields for boxed types
  + Support "copy construction" of boxed types
  + Support simple structures not registered as boxed
  - Allow access to nested structures
  - Allow direct assignment to nested structure fields
  - Allow enum and flag structure fields
  - Allow creating boxed wrapper without copy
  + Support for non-default constructor (i.e. constructors like
    GdkPixbuf.Pixbuf.new_from_file(file))
  + Add a Lang.bind function which binds the meaning of 'this'
  + Add an interactive console gjs-console
  + Allow code in directory modules (i.e. the code should reside in
    __init__.js files)
  + Fix handling of enum/flags return values
  + Handle non-gobject-registered flags
  + Add Tweener.registerSpecialProperty to tweener module
  + Add profiler for javascript code
  + Add gjs_context_get_all and gjs_dumpstack - useful to invoke
    from a debugger such as gdb
  + Support GHashTable
  + Add support for UNIX shebang (i.e. #!/usr/bin/gjs-console)
  + Support new introspection short/ushort type tags
  + Support GI_TYPE_TAG_FILENAME
  + Improve support for machine-dependent integer types and arrays
    of integers
  + Fix several memory leaks
  + Bugs fixed: bgo#560506, bgo#560670, bgo#560808, bgo#561514,
    bgo#561516, bgo#561849, bgo#562892, bgo#564424, bgo#564664,
    bgo#566185, bgo#567675, bgo#569178, bgo#570775, bgo#570964,
    bgo#580948, bgo#584560, bgo#584850, bgo#584858, bgo#584858,
    bgo#585386, bgo#585460, bgo#586665, bgo#586760, bgo#561203,
    bgo#561573, bgo#561585, bgo#561664, bgo#561686, bgo#561812,
    bgo#562575, bgo#565029, bgo#567078, bgo#569374, bgo#572113,
    bgo#572121, bgo#572130, bgo#572258, bgo#580865, bgo#580947,
    bgo#580957, bgo#581277, bgo#581384, bgo#581385, bgo#581389,
    bgo#582686, bgo#582704, bgo#582707, bgo#584849, bgo#560808
- Add dbus-1-glib-devel BuildRequires.
* Fri May  1 2009 vuntz@novell.com
- Initial package.
